# 2023-02-08 - Euler Linear Pool

First deployment of the `EulerLinearPoolFactory`, for Linear Pools with an Euler yield-bearing token.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`EulerLinearPoolFactory` artifact](./artifact/EulerLinearPoolFactory.json)
